@@ -4,23 +4,23 @@ use Mojo::Base -base;
 use Mojo::Collection;
 use Mojo::Util 'tablify';
 
-our $VERSION = '0.005';
+our $VERSION = '0.006';
 
 has 'sth';
 
 sub DESTROY { $_[0]{sth}->finish if $_[0]{sth} }
 
-sub array { ($_[0]->sth->fetchrow_arrayref)[0] }
+sub array { (shift->sth->fetchrow_arrayref)[0] }
 
-sub arrays { _collect(@{$_[0]->sth->fetchall_arrayref}) }
+sub arrays { _collect(@{shift->sth->fetchall_arrayref}) }
 
 sub columns { shift->sth->{NAME} }
 
-sub hash { ($_[0]->sth->fetchrow_hashref)[0] }
+sub hash { (shift->sth->fetchrow_hashref)[0] }
 
-sub hashes { _collect(@{$_[0]->sth->fetchall_arrayref({})}) }
+sub hashes { _collect(@{shift->sth->fetchall_arrayref({})}) }
 
-sub rows { scalar @{shift->arrays} }
+sub rows { shift->sth->rows }
 
 sub text { tablify shift->arrays }
 
@@ -112,7 +112,8 @@ containing hash references.
 
   my $num = $results->rows;
 
-Number of rows.
+Number of rows. Note that for C<SELECT> statements, this count will not be
+accurate until all rows have been fetched.
 
 =head2 text
 
